========
Meditate
========

A command line meditation clock.

Installation:
-------------

* user install: ::

    pip install --user meditate

* system wide (why would you do such a thing?): ::

    sudo pip install meditate

Copyright
---------

* The `meditate package`_ is released under the `AGPL-3.0-or-later`_.

* The `bell sound`_, taken from `freesound.org`_, is licensed under
  CC0_.


.. _`bell sound`: sound/140128__jetrye__bell-meditation-cleaned.wav
.. _freesound.org: https://freesound.org/people/JetRye/sounds/140128/
.. _CC0: https://creativecommons.org/publicdomain/zero/1.0/
.. _`meditate package`: https://pypi.python.org/pypi/meditate/
.. _`AGPL-3.0-or-later`: https://www.gnu.org/licenses/agpl-3.0.en.html
